# pc_mouseparty


[![image](https://img.shields.io/pypi/v/pc_mouseparty.svg)](https://pypi.python.org/pypi/pc_mouseparty)
<!-- [![image](https://img.shields.io/conda/vn/conda-forge/pc_mouseparty.svg)](https://anaconda.org/conda-forge/pc_mouseparty) -->
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![image](https://github.com/gee-community/geemap/workflows/docs/badge.svg)](https://padillacoreanolab.github.io/pc_mouseparty)


**A package for all the base functions used in the Padilla-Coreano lab.**


-   Free software: MIT license
-   Documentation: https://padillacoreanolab.github.io/pc_mouseparty
-   Pypi: https://pypi.org/project/pc-mouseparty
    

## Features

-   How to update a release:
    1. create a conda environment with dependencies in requirements_dev.txt
    2. activate environment to make use of bump2version
    3. pull latest amster branch and have it checked out
    4. run `bumpversion <major/minor/patch>` (to set a specific version use `bumpversion --new-version <major#.minor#.patch#> <major/minor/patch>`)
    5. run `git push --tags`
    6. run `git push` to push the master branch to origin or just push the mster to origin using a git client
    7. Go to github and use tags menu to create and publish a new release

    update docs test on gh repo

